# API Reference

## Drawing functions

```{eval-rst}
.. autofunction:: demesdraw.size_history
.. autofunction:: demesdraw.tubes
```

## Utility functions

```{eval-rst}
.. autofunction:: demesdraw.utils.get_fig_axes
.. autofunction:: demesdraw.utils.size_max
.. autofunction:: demesdraw.utils.size_min
.. autofunction:: demesdraw.utils.log_size_heuristic
.. autofunction:: demesdraw.utils.log_time_heuristic
.. autofunction:: demesdraw.utils.separation_heuristic
.. autofunction:: demesdraw.utils.minimal_crossing_positions
.. autofunction:: demesdraw.utils.optimise_positions
```
